#! /bin/sh


# The following two are the ANSI sequences for start and end embolden
case $TERM in
vt*|ansi*|con*|xterm*|linux*|screen*)
  S=[1m
  E=[m
  ;;
*)
  S=
  E=
  ;;
esac

PW_DIR=`pwd`

if test x$UID != x; then
  TRUST="--with-trusted=0,2,$UID"
else
  TRUST="--with-trusted=0,2"
fi

echo; echo "${S}__ STARTING TEST COMPILE __${E}"; echo;
echo Working directory: $PW_DIR

MAKE=`which gmake | sed -e "s%\([a-z:]\) .*%\1%g"` 
if test x$MAKE = x; then
	MAKE="make -s"
elif test x$MAKE = xno; then
	MAKE="make -s"
else
	if test "x$MAKE" = "xwhich:"; then
		MAKE="make -s"
	else
		MAKE="gmake -s"
	fi
fi
echo MAKE is $MAKE
echo


testcompile ()
{
	#
	# test standalone compilation
	#
	echo "${S}Building standalone agent${E}"; echo;
	#
	if test -r "Makefile"; then
		$MAKE distclean
	fi
	#
	./configure --quiet  --prefix=$PW_DIR --with-dataroot-prefix=$PW_DIR --with-config-file=$PW_DIR/samhainrc.test   
	#
	if test x$? = x0; then
		echo "configure completed, exit status 0"; echo;
		$MAKE  > /dev/null
		echo "$MAKE completed, exit status $?"; echo;
	else
		echo "ERROR: configure failed"; echo;
	fi

	#
	# test standalone compilation with --with-nocl=PW
	#
	echo "${S}Building standalone agent${E}"; echo;
	#
	if test -r "Makefile"; then
		$MAKE distclean
	fi
	#
	./configure --quiet  --prefix=$PW_DIR --with-nocl="owl" --with-dataroot-prefix=$PW_DIR --with-config-file=$PW_DIR/samhainrc.test   
	#
	if test x$? = x0; then
		echo "configure completed, exit status 0"; echo;
		$MAKE  > /dev/null
		echo "$MAKE completed, exit status $?"; echo;
	else
		echo "ERROR: configure failed"; echo;
	fi

	#
	# test standalone compilation w/ debug
	#
	echo "${S}Building standalone agent w/debug${E}"; echo;
	#
	if test -r "Makefile"; then
		$MAKE distclean
	fi
	#
	./configure --quiet --enable-debug  --prefix=$PW_DIR --with-dataroot-prefix=$PW_DIR --with-config-file=$PW_DIR/samhainrc.test   
	#
	if test x$? = x0; then
		echo "configure completed, exit status 0"; echo;
		$MAKE  > /dev/null
		echo "$MAKE completed, exit status $?"; echo;
	else
		echo "ERROR: configure failed"; echo;
	fi

	#
	# test standalone compilation w/ gpg
	#
	echo "${S}Building standalone agent w/gpg${E}"; echo;
	#
	if test -r "Makefile"; then
		$MAKE distclean
	fi
	#
	./configure --quiet --with-gpg=/usr/bin/gpg  --prefix=$PW_DIR --with-dataroot-prefix=$PW_DIR --with-config-file=$PW_DIR/samhainrc.test   
	#
	if test x$? = x0; then
		echo "configure completed, exit status 0"; echo;
		$MAKE  > /dev/null
		echo "$MAKE completed, exit status $?"; echo;
	else
		echo "ERROR: configure failed"; echo;
	fi

	#
	# test standalone compilation w/ pgp
	#
	echo "${S}Building standalone agent w/pgp${E}"; echo;
	#
	if test -r "Makefile"; then
		$MAKE distclean
	fi
	#
	./configure --quiet --with-pgp=/usr/bin/pgp  --prefix=$PW_DIR --with-dataroot-prefix=$PW_DIR --with-config-file=$PW_DIR/samhainrc.test   
	#
	if test x$? = x0; then
		echo "configure completed, exit status 0"; echo;
		$MAKE  > /dev/null
		echo "$MAKE completed, exit status $?"; echo;
	else
		echo "ERROR: configure failed"; echo;
	fi

	#
	# test standalone compilation w/stealth
	#
	echo "${S}Building standalone agent w/stealth${E}"; echo;
	#
	if test -r "Makefile"; then
		$MAKE distclean
	fi
	#
	./configure --quiet --with-stealth=128 --prefix=$PW_DIR --with-dataroot-prefix=$PW_DIR --with-config-file=$PW_DIR/samhainrc.test   
	#
	if test x$? = x0; then
		echo "configure completed, exit status 0"; echo;
		$MAKE  > /dev/null
		echo "$MAKE completed, exit status $?"; echo;
	else
		echo "ERROR: configure failed"; echo;
	fi

	#
	# test standalone compilation w/logwatch
	#
	echo "${S}Building standalone agent w/login-watch${E}"; echo;
	#
	if test -r "Makefile"; then
		$MAKE distclean
	fi
	#
	./configure --quiet --enable-login-watch  --prefix=$PW_DIR --with-dataroot-prefix=$PW_DIR --with-config-file=$PW_DIR/samhainrc.test   
	#
	if test x$? = x0; then
		echo "configure completed, exit status 0"; echo;
		$MAKE  > /dev/null
		echo "$MAKE completed, exit status $?"; echo;
	else
		echo "ERROR: configure failed"; echo;
	fi

	#
	# test standalone compilation
	#
	echo "${S}Building standalone agent w/o mail${E}"; echo;
	#
	if test -r "Makefile"; then
		$MAKE distclean
	fi
	#
	./configure --quiet --disable-mail --prefix=$PW_DIR --with-dataroot-prefix=$PW_DIR --with-config-file=$PW_DIR/samhainrc.test   
	#
	if test x$? = x0; then
		echo "configure completed, exit status 0"; echo;
		$MAKE  > /dev/null
		echo "$MAKE completed, exit status $?"; echo;
	else
		echo "ERROR: configure failed"; echo;
	fi

	#
	# test standalone compilation
	#
	echo "${S}Building standalone agent w/o external scripts${E}"; echo;
	#
	if test -r "Makefile"; then
		$MAKE distclean
	fi
	#
	./configure --quiet --disable-external-scripts --prefix=$PW_DIR --with-dataroot-prefix=$PW_DIR --with-config-file=$PW_DIR/samhainrc.test   
	#
	if test x$? = x0; then
		echo "configure completed, exit status 0"; echo;
		$MAKE  > /dev/null
		echo "$MAKE completed, exit status $?"; echo;
	else
		echo "ERROR: configure failed"; echo;
	fi

	echo; echo "${S}__ TEST CLIENT/SERVER __${E}"; echo;

	#
	# test client/server compilation
	#
	echo "${S}Building client/server application${E}"; echo;
	#
	if test -r "Makefile"; then
		$MAKE distclean
	fi
	#
	./configure --quiet --enable-network  --enable-srp --prefix=$PW_DIR --with-dataroot-prefix=$PW_DIR --with-config-file=$PW_DIR/samhainrc.test   
	#
	if test x$? = x0; then
		echo "configure completed, exit status 0"; echo;
		$MAKE  > /dev/null
		echo "$MAKE completed, exit status $?"; echo;
	else
		echo "ERROR: configure failed"; echo;
	fi

	#
	# test c/s compilation w/ gpg
	#
	echo "${S}Building client/server application w/gpg${E}"; echo;
	#
	if test -r "Makefile"; then
		$MAKE distclean
	fi
	#
	./configure --quiet --enable-network  --enable-srp --with-gpg=/usr/bin/gpg  --prefix=$PW_DIR --with-dataroot-prefix=$PW_DIR --with-config-file=$PW_DIR/samhainrc.test   
	#
	if test x$? = x0; then
		echo "configure completed, exit status 0"; echo;
		$MAKE  > /dev/null
		echo "$MAKE completed, exit status $?"; echo;
	else
		echo "ERROR: configure failed"; echo;
	fi

	#
	# test c/s compilation w/ pgp
	#
	echo "${S}Building client/server application w/pgp${E}"; echo;
	#
	if test -r "Makefile"; then
		$MAKE distclean
	fi
	#
	./configure --quiet --with-pgp=/usr/bin/pgp --enable-network  --enable-srp --prefix=$PW_DIR --with-dataroot-prefix=$PW_DIR --with-config-file=$PW_DIR/samhainrc.test   
	#
	if test x$? = x0; then
		echo "configure completed, exit status 0"; echo;
		$MAKE  > /dev/null
		echo "$MAKE completed, exit status $?"; echo;
	else
		echo "ERROR: configure failed"; echo;
	fi

	#
	# test client/server compilation
	#
	echo "${S}Building client/server application w/o srp${E}"; echo;
	#
	if test -r "Makefile"; then
		$MAKE distclean
	fi
	#
	./configure --quiet --enable-network  --prefix=$PW_DIR --with-dataroot-prefix=$PW_DIR --with-config-file=$PW_DIR/samhainrc.test   
	#
	if test x$? = x0; then
		echo "configure completed, exit status 0"; echo;
		$MAKE  > /dev/null
		echo "$MAKE completed, exit status $?"; echo;
	else
		echo "ERROR: configure failed"; echo;
	fi

	#
	# test client/server compilation w/ debug
	#
	echo "${S}Building client/server application w/debug${E}"; echo;
	#
	if test -r "Makefile"; then
		$MAKE distclean
	fi
	#
	./configure --quiet --enable-network --enable-debug --prefix=$PW_DIR --with-dataroot-prefix=$PW_DIR --with-config-file=$PW_DIR/samhainrc.test   
	#
	if test x$? = x0; then
		echo "configure completed, exit status 0"; echo;
		$MAKE  > /dev/null
		echo "$MAKE completed, exit status $?"; echo;
	else
		echo "ERROR: configure failed"; echo;
	fi

	#
	# test client/server compilation w/stealth
	#
	echo "${S}Building client/server application w/stealth${E}"; echo;
	#
	if test -r "Makefile"; then
		$MAKE distclean
	fi
	#
	./configure --quiet --enable-network  --enable-srp --with-stealth=128 --prefix=$PW_DIR --with-dataroot-prefix=$PW_DIR --with-config-file=$PW_DIR/samhainrc.test   
	#
	if test x$? = x0; then
		echo "configure completed, exit status 0"; echo;
		$MAKE  > /dev/null
		echo "$MAKE completed, exit status $?"; echo;
	else
		echo "ERROR: configure failed"; echo;
	fi

	#
	# test  client/server compilation w/logwatch
	#
	echo "${S}Building client/server application w/login-watch${E}"; echo;
	#
	if test -r "Makefile"; then
		$MAKE distclean
	fi
	#
	./configure --quiet --enable-network  --enable-srp --enable-login-watch --prefix=$PW_DIR --with-dataroot-prefix=$PW_DIR --with-config-file=$PW_DIR/samhainrc.test   
	#
	if test x$? = x0; then
		echo "configure completed, exit status 0"; echo;
		$MAKE  > /dev/null
		echo "$MAKE completed, exit status $?"; echo;
	else
		echo "ERROR: configure failed"; echo;
	fi

	#
	# test client/server compilation
	#
	echo "${S}Building client/server application w/o mail${E}";
	echo;
	#
	if test -r "Makefile"; then
		$MAKE distclean
	fi
	#
	./configure --quiet --enable-network  --enable-srp --with-stealth=128 --enable-debug --prefix=$PW_DIR --with-dataroot-prefix=$PW_DIR --with-config-file=$PW_DIR/samhainrc.test   
	#
	if test x$? = x0; then
		echo "configure completed, exit status 0"; echo;
		$MAKE  > /dev/null
		echo "$MAKE completed, exit status $?"; echo;
	else
		echo "ERROR: configure failed"; echo;
	fi

	#
	# test client/server compilation
	#
	echo "${S}Building client/server application w/o external scripts${E}";
	echo;
	#
	if test -r "Makefile"; then
		$MAKE distclean
	fi
	#
	./configure --quiet --enable-network  --enable-srp --disable-external-scripts --prefix=$PW_DIR --with-dataroot-prefix=$PW_DIR --with-config-file=$PW_DIR/samhainrc.test   
	#
	if test x$? = x0; then
		echo "configure completed, exit status 0"; echo;
		$MAKE  > /dev/null
		echo "$MAKE completed, exit status $?"; echo;
	else
		echo "ERROR: configure failed"; echo;
	fi
}



	testcompile


echo; echo "${S}__ END TEST COMPILE __${E}"; echo;

exit

